@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,71 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class DescribeConfigRequest(AbstractModel):
+    """DescribeConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: 实例ID
+        :type InstanceId: str
+        :param Type: 配置中心类型（consul、zookeeper、apollo等）
+        :type Type: str
+        :param Key: 配置项的节点路径key
+        :type Key: str
+        """
+        self.InstanceId = None
+        self.Type = None
+        self.Key = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.Type = params.get("Type")
+        self.Key = params.get("Key")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeConfigResponse(AbstractModel):
+    """DescribeConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Key: 配置项或路径key
+        :type Key: str
+        :param Value: 配置项的值
+        :type Value: str
+        :param IsDir: 当前key是否为路径
+        :type IsDir: bool
+        :param List: 当前key下的子路径
+        :type List: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Key = None
+        self.Value = None
+        self.IsDir = None
+        self.List = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        self.IsDir = params.get("IsDir")
+        self.List = params.get("List")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeSREInstanceAccessAddressRequest(AbstractModel):
     """DescribeSREInstanceAccessAddress请求参数结构体
 
@@ -38,7 +103,7 @@ class DescribeSREInstanceAccessAddressRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -51,23 +116,20 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
         """
         :param IntranetAddress: 内网访问地址
         :type IntranetAddress: str
+        :param InternetAddress: 公网访问地址
+        :type InternetAddress: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.IntranetAddress = None
+        self.InternetAddress = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.IntranetAddress = params.get("IntranetAddress")
+        self.InternetAddress = params.get("InternetAddress")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeSREInstancesRequest(AbstractModel):
@@ -103,7 +165,7 @@ class DescribeSREInstancesRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -135,13 +197,6 @@ class DescribeSREInstancesResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Content.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class Filter(AbstractModel):
@@ -168,7 +223,7 @@ class Filter(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -208,7 +263,7 @@ class ManageConfigRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -222,23 +277,21 @@ class ManageConfigResponse(AbstractModel):
         :param Result: 对配置中心操作配置之后的返回值
 注意：此字段可能返回 null，表示取不到有效值。
         :type Result: str
+        :param OpResult: 操作是否成功
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OpResult: bool
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.Result = None
+        self.OpResult = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.Result = params.get("Result")
+        self.OpResult = params.get("OpResult")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class SREInstance(AbstractModel):
@@ -279,6 +332,12 @@ class SREInstance(AbstractModel):
         :param Paymode: 计费方式
 注意：此字段可能返回 null，表示取不到有效值。
         :type Paymode: str
+        :param EKSClusterID: EKS集群的ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EKSClusterID: str
+        :param CreateTime: 集群创建时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreateTime: str
         """
         self.InstanceId = None
         self.Name = None
@@ -293,6 +352,8 @@ class SREInstance(AbstractModel):
         self.StorageType = None
         self.StorageCapacity = None
         self.Paymode = None
+        self.EKSClusterID = None
+        self.CreateTime = None
 
 
     def _deserialize(self, params):
@@ -309,10 +370,12 @@ class SREInstance(AbstractModel):
         self.StorageType = params.get("StorageType")
         self.StorageCapacity = params.get("StorageCapacity")
         self.Paymode = params.get("Paymode")
+        self.EKSClusterID = params.get("EKSClusterID")
+        self.CreateTime = params.get("CreateTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
